@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * License along with this library; if not, see <https://www.gnu.org/licenses/>.
  *
  * Copyright 2006, 2007 Øyvind Kolås <pippin@gimp.org>
  */
@@ -240,7 +240,11 @@ gboolean          gegl_buffer_set_abyss      (GeglBuffer          *buffer,
  * Valid values: GEGL_ABYSS_NONE (abyss pixels are zeroed), GEGL_ABYSS_WHITE
  * (abyss pixels are white), GEGL_ABYSS_BLACK (abyss pixels are black),
  * GEGL_ABYSS_CLAMP (coordinates are clamped to the abyss rectangle),
- * GEGL_ABYSS_LOOP (buffer contents are tiled if outside of the abyss rectangle).
+ * GEGL_ABYSS_LOOP (buffer contents are tiled if outside of the abyss rectangle)
+ * this argument also takes a GEGL_BUFFER_FILTER value or'ed into it, allowing
+ * to specify trade-off of performance/quality, valid values are:
+ * GEGL_BUFFER_FILTER_NEAREST, GEGL_BUFFER_FILTER_BILINEAR,
+ * GEGL_BUFFER_FILTER_BOX and GEGL_BUFFER_FILTER_AUTO.
  *
  * Fetch a rectangular linear buffer of pixel data from the GeglBuffer, the
  * data is converted to the desired BablFormat, if the BablFormat stored and
@@ -411,8 +415,11 @@ GeglBuffer *    gegl_buffer_dup               (GeglBuffer       *buffer);
  * GEGL_ABYSS_LOOP (buffer contents are tiled if outside of the abyss rectangle).
  *
  * Query interpolate pixel values at a given coordinate using a specified form
- * of interpolation. The samplers used cache for a small neighbourhood of the
- * buffer for more efficient access.
+ * of interpolation.
+ *
+ * If you intend to take multiple samples, consider using
+ * gegl_buffer_sampler_new_at_level() to create a sampler object instead, which
+ * is more efficient.
  */
 
 void              gegl_buffer_sample_at_level (GeglBuffer       *buffer,
@@ -445,8 +452,11 @@ void              gegl_buffer_sample_at_level (GeglBuffer       *buffer,
  * GEGL_ABYSS_LOOP (buffer contents are tiled if outside of the abyss rectangle).
  *
  * Query interpolate pixel values at a given coordinate using a specified form
- * of interpolation. The samplers used cache for a small neighbourhood of the
- * buffer for more efficient access.
+ * of interpolation.
+ *
+ * If you intend to take multiple samples, consider using
+ * gegl_buffer_sampler_new() to create a sampler object instead, which is more
+ * efficient.
  */
 void              gegl_buffer_sample          (GeglBuffer       *buffer,
                                                gdouble           x,
@@ -463,11 +473,12 @@ void              gegl_buffer_sample          (GeglBuffer       *buffer,
  * gegl_buffer_sample_cleanup:
  * @buffer: the GeglBuffer to sample from
  *
- * Clean up resources used by sampling framework of buffer (will be freed
- * automatically later when the buffer is destroyed, for long lived buffers
- * cleaning up the sampling infrastructure when it has been used for its
- * purpose will sometimes be more efficient).
+ * Clean up resources used by sampling framework of buffer.
+ *
+ * Deprecated: 0.4.2: This function has no effect. It is not necessary to call
+ * it after using gegl_buffer_sample() or gegl_buffer_sample_at_level().
  */
+G_DEPRECATED
 void            gegl_buffer_sample_cleanup    (GeglBuffer *buffer);
 
 typedef void (*GeglSamplerGetFun)  (GeglSampler     *self,
